Author: stsp
Date: Wed Apr 25 13:51:15 2012
New Revision: 1330295

URL: http://svn.apache.org/viewvc?rev=1330295&view=rev
Log:
Improve wording used in comments and an error message in the diff code.

* subversion/libsvn_client/diff.c
  (check_paths): Not many will understand what a "non-local" revision is. Those
    who do understand this error message have propably read the code of this
    function. So use the more widely known "BASE and WORKING" terminology.

Modified:
    subversion/trunk/subversion/libsvn_client/diff.c

Modified: subversion/trunk/subversion/libsvn_client/diff.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/diff.c?rev=1330295&r1=1330294&r2=1330295&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/diff.c (original)
+++ subversion/trunk/subversion/libsvn_client/diff.c Wed Apr 25 13:51:15 2012
@@ -1409,7 +1409,8 @@ convert_to_url(const char **url,
 
 /** Check if paths PATH_OR_URL1 and PATH_OR_URL2 are urls and if the
  * revisions REVISION1 and REVISION2 are local. If PEG_REVISION is not
  * unspecified, ensure that at least one of the two revisions is non-local.
  * If PATH_OR_URL1 can only be found in the repository, set *IS_REPOS1
  * to TRUE. If PATH_OR_URL2 can only be found in the repository, set
  * *IS_REPOS2 to TRUE. */
@@ -1430,8 +1431,8 @@ check_paths(svn_boolean_t *is_repos1,
     return svn_error_create(SVN_ERR_CLIENT_BAD_REVISION, NULL,
                             _("Not all required revisions are specified"));
 
-  /* Revisions can be said to be local or remote.  BASE and WORKING,
-     for example, are local.  */
+  /* Revisions can be said to be local or remote.
+   * BASE and WORKING are local revisions.  */
   is_local_rev1 =
     ((revision1->kind == svn_opt_revision_base)
      || (revision1->kind == svn_opt_revision_working));
@@ -1442,8 +1443,8 @@ check_paths(svn_boolean_t *is_repos1,
   if (peg_revision->kind != svn_opt_revision_unspecified &&
       is_local_rev1 && is_local_rev2)
     return svn_error_create(SVN_ERR_CLIENT_BAD_REVISION, NULL,
-                            _("At least one revision must be non-local "
-                              "for a pegged diff"));
+                            _("At least one revision must be something other "
+                              "than BASE or WORKING when diffing a URL"));
 
   /* Working copy paths with non-local revisions get turned into
      URLs.  We don't do that here, though.  We simply record that it
@@ -1409,7 +1409,8 @@ convert_to_url(const char **url,
 /** Check if paths PATH_OR_URL1 and PATH_OR_URL2 are urls and if the
  * revisions REVISION1 and REVISION2 are local. If PEG_REVISION is not
- * unspecified, ensure that at least one of the two revisions is non-local.
+ * unspecified, ensure that at least one of the two revisions is not
+ * BASE or WORKING.
  * If PATH_OR_URL1 can only be found in the repository, set *IS_REPOS1
  * to TRUE. If PATH_OR_URL2 can only be found in the repository, set


Reply via email to